==> kik-botmill-1.0.2-sources.jar: co/aurasphere/botmill/kik/KikBotMillEntry.java <==
/**
 * 
 * MIT License
 *
 * Copyright (c) 2017 BotMill.io
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 * 
 */
package co.aurasphere.botmill.kik;

/**
 * The Class KikBot.
 * 
 * @author Alvin P. Reyes
 */
public abstract class KikBotMillEntry {
	
	/**
	 * Instantiates a new kik bot.
	 */
	public KikBotMillEntry() {
		KikBotMillContext.getInstance().registerEntryPoint(this);
		this.postCleanup(); // clean up all the stuff.
	}
	
	/**
	 * Sets the web hook url.
	 *
	 * @param url the new web hook url
	 */
	protected void setWebHookUrl(String url) {
		KikBotMillContext.getInstance().setWebHookUrl(url);
	}
	
	/**
	 * Define kik bot.
	 */
	protected abstract void kikBotEntry();
	
	/**
	 * Post cleanup.
	 */
	protected void postCleanup() {
		
	}
}

==> kik-botmill-1.1.0-sources.jar: co/aurasphere/botmill/kik/KikBotMillEntry.java <==
/**
 * 
 * MIT License
 *
 * Copyright (c) 2017 BotMill.io
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 * 
 */
package co.aurasphere.botmill.kik;

/**
 * The Class KikBot.
 * 
 * This is the abstract class that needs to be inherited by any
 * EntryPoint class that the developer needs to register.
 * 
 * @author Alvin P. Reyes
 */
public abstract class KikBotMillEntry {
	
	/**
	 * Instantiates a new kik bot.
	 */
	public KikBotMillEntry() {
		KikBotMillContext.getInstance().registerEntryPoint(this);
		this.postCleanup(); // clean up all the stuff.
	}
	
	/**
	 * Sets the web hook url.
	 *
	 * @param url the new web hook url
	 */
	protected void setWebHookUrl(String url) {
		KikBotMillContext.getInstance().setWebHookUrl(url);
	}
	
	/**
	 * Define kik bot.
	 */
	protected abstract void kikBotEntry();
	
	/**
	 * Post cleanup.
	 */
	protected void postCleanup() {
		
	}
}
